ResultModel class

Constructors

ResultModel(double pressure, double temperature, int index, int alarmtype)

Properties

alarmtype int
final
hashCode int
The hash code for this object.
no setterinherited
index int
final
pressure double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temperature double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited